==> bs-react-native-0.4.0.tgz: package/STATUS.md <==

# Status

## Components
- [ ] ART
- [x] ActivityIndicator
- [x] Button
- [x] DatePickerIOS
- [ ] DrawerLayoutAndroid
- [x] FlatList
- [x] Image
- [x] Image Background
- [ ] KeyboardAvoidingView
- [ ] ListView
- [ ] MapView
- [x] Modal
- [x] Picker
- [ ] PickerIOS
- [ ] ProgressBarAndroid
- [ ] ProgressViewIOS
- [x] RefreshControl
- [x] ScrollView
- [x] SectionList
- [x] SegmentedControlIOS
- [x] Slider
- [ ] SnapshotViewIOS
- [x] StatusBar
- [x] Switch
- [x] TabBarIOS
- [x] TabBarIOS.Item
- [x] Text
- [x] TextInput
- [ ] ToolbarAndroid
- [x] TouchableHighlight
- [ ] TouchableNativeFeedback
- [x] TouchableOpacity
- [x] TouchableWithoutFeedback
- [x] View
- [ ] ViewPagerAndroid
- [ ] VirtualizedList
- [ ] WebView


## APIs
- [ ] AccessibilityInfo
- [ ] ActionSheetIOS
- [ ] AdSupportIOS
- [x] Alert
- [x] AlertIOS
- [x] Animated
- [x] AppRegistry
- [x] AppState
- [x] AsyncStorage
- [x] BackHandler
- [ ] CameraRoll
- [ ] Clipboard
- [ ] DatePickerAndroid
- [x] Dimensions
- [ ] Easing
- [ ] Geolocation
- [ ] ImageEditor
- [ ] ImagePickerIOS
- [ ] ImageStore
- [ ] InteractionManager
- [ ] Keyboard
- [ ] LayoutAnimation
- [ ] Linking
- [x] NativeEventEmitter
- [ ] NativeMethodsMixin
- [x] NativeModules
- [ ] NetInfo
- [x] PanResponder
- [ ] PermissionsAndroid
- [x] PixelRatio
- [x] Platform
- [ ] PushNotificationIOS
- [ ] Settings
- [ ] Share
- [ ] StatusBarIOS
- [x] StyleSheet
- [ ] Systrace
- [ ] TimePickerAndroid
- [ ] ToastAndroid
- [x] Vibration
- [x] Layout Props
- [x] Shadow Props

==> bs-react-native-0.6.0.tgz: package/STATUS.md <==

# Status

## Components
- [ ] ART
- [x] ActivityIndicator
- [x] Button
- [x] DatePickerIOS
- [ ] DrawerLayoutAndroid
- [x] FlatList
- [x] Image
- [x] Image Background
- [ ] KeyboardAvoidingView
- [ ] ListView
- [ ] MapView
- [x] Modal
- [x] Picker
- [ ] PickerIOS
- [ ] ProgressBarAndroid
- [ ] ProgressViewIOS
- [x] RefreshControl
- [x] ScrollView
- [x] SectionList
- [x] SegmentedControlIOS
- [x] Slider
- [ ] SnapshotViewIOS
- [x] StatusBar
- [x] Switch
- [x] TabBarIOS
- [x] TabBarIOS.Item
- [x] Text
- [x] TextInput
- [ ] ToolbarAndroid
- [x] TouchableHighlight
- [ ] TouchableNativeFeedback
- [x] TouchableOpacity
- [x] TouchableWithoutFeedback
- [x] View
- [ ] ViewPagerAndroid
- [ ] VirtualizedList
- [ ] WebView


## APIs
- [ ] AccessibilityInfo
- [x] ActionSheetIOS
- [ ] AdSupportIOS
- [x] Alert
- [x] AlertIOS
- [x] Animated
- [x] AppRegistry
- [x] AppState
- [x] AsyncStorage
- [x] BackHandler
- [x] CameraRoll
- [x] Clipboard
- [x] DatePickerAndroid
- [x] Dimensions
- [x] Easing
- [ ] Geolocation
- [ ] ImageEditor
- [ ] ImagePickerIOS
- [ ] ImageStore
- [ ] InteractionManager
- [x] Keyboard
- [ ] LayoutAnimation
- [ ] Linking
- [x] NativeEventEmitter
- [ ] NativeMethodsMixin
- [x] NativeModules
- [x] NetInfo
- [x] PanResponder
- [ ] PermissionsAndroid
- [x] PixelRatio
- [x] Platform
- [ ] PushNotificationIOS
- [ ] Settings
- [ ] Share
- [ ] StatusBarIOS
- [x] StyleSheet
- [ ] Systrace
- [ ] TimePickerAndroid
- [ ] ToastAndroid
- [x] Vibration
- [x] Layout Props
- [x] Shadow Props
